@@ -1192,9 +1192,10 @@ freq_base = 0
 #freq_base = 12500
 
 ## invertSpectrum       Invert the RF spectrum, integer choice
-# If your mixing scheme inverts the RF spectrum, set this option to un-invert it.
-invertSpectrum = 0      # Do not invert
-#invertSpectrum = 1     # Invert spectrum
+# If your mixing scheme inverts the RF spectrum, set this option to 1 to un-invert it.
+# Otherwise set it to 0.
+invertSpectrum = 0
+#invertSpectrum = 1
 
 # This is a list of mixer settings.  It only works for Linux; it has no effect in Windows.
 # Use "amixer -c 1 contents" to get a list of mixer controls and their numid's for
@@ -1346,7 +1347,7 @@ hamlib_com2_name = ""
 
 
 ################ Keys
-## hot_key_ptt1		PTT Key 1, keycode
+## hot_key_ptt1		PTT shortcut key 1, keycode
 # Set a keyboard shortcut that will press the PTT button.
 # For a regular key, use the ord() of the key.  For example, ord('a') or ord('b').  For the space bar
 # use ord(' ').  Then restart Quisk.
@@ -1359,7 +1360,7 @@ hot_key_ptt1 = None
 #hot_key_ptt1 = ord('a')
 #hot_key_ptt1 = wx.WXK_F5
 
-## hot_key_ptt2		PTT Key 2, keycode
+## hot_key_ptt2		PTT shortcut key 2, keycode
 # If the Control or Shift key must be pressed too, set that key modifier here.
 # Otherwise, set NORMAL here.
 # For example, if you want control-A, set CTRL in "PTT Key 2", and ord('a') in "PTT Key 1".
@@ -1369,7 +1370,7 @@ hot_key_ptt2 = wx.ACCEL_NORMAL
 #hot_key_ptt2 = wx.ACCEL_CTRL | wx.ACCEL_SHIFT
 #hot_key_ptt2 = wx.ACCEL_ALT
 
-## hot_key_ptt_toggle	PTT Key Toggle, boolean
+## hot_key_ptt_toggle	PTT key toggle, boolean
 # Set to True if you want PTT to remain on when you release the key.  A second key press will
 # then release PTT.  This is toggle mode.  If False, you must keep pressing the key, and releasing
 # it will release PTT.
@@ -1377,12 +1378,27 @@ hot_key_ptt2 = wx.ACCEL_NORMAL
 hot_key_ptt_toggle = False
 #hot_key_ptt_toggle = True
 
-## hot_key_ptt_if_hidden	PTT Key if Hidden, boolean
+## hot_key_ptt_if_hidden	PTT key if hidden, boolean
 # Set to True if you want PTT to be active when the Quisk window is not visible.
 # Otherwise, the Quisk window must be active and on top.
 hot_key_ptt_if_hidden = False
 #hot_key_ptt_if_hidden = True
 
+## midi_cwkey_device                          Midi device name, text
+# The name of the MIDI device that will be used for CW keying, PTT or other control. Leave this blank if you
+# are not using MIDI.
+midi_cwkey_device = ''
+
+## midi_cwkey_note				Midi note for CW key, integer
+# If you have a CW key attached to a MIDI device, enter the note number for the CW key.
+# MIDI devices can send KeyUp and KeyDown messages that can be used for CW keying.
+# MIDI note numbers are integers. Middle C is number 60. The A above (440 Hz) is 69.
+# For microcontrollers, refer to its documentation for the correct note number.
+midi_cwkey_note = -1
+#midi_cwkey_note = 60
+#midi_cwkey_note = 69
+
+
 
 
 
@@ -1638,20 +1654,6 @@ quisk_serial_dsr = "None"
 #quisk_serial_dsr = "PTT when high"
 #quisk_serial_dsr = "PTT when low"
 
-## midi_cwkey_device                          Midi CW key device, text
-# The name of the MIDI device that will be used for CW keying. Leave this blank if you
-# are not using MIDI keying.
-midi_cwkey_device = ''
-
-## midi_cwkey_note				Midi note for CW key, integer
-# If you have a CW key attached to a MIDI device, enter the note number for the CW key.
-# MIDI devices can send KeyUp and KeyDown messages that can be used for CW keying.
-# MIDI note numbers are integers. Middle C is number 60. The A above (440 Hz) is 69.
-# For microcontrollers, refer to its documentation for the correct note number.
-midi_cwkey_note = -1
-#midi_cwkey_note = 60
-#midi_cwkey_note = 69
-
 
 
 ################ Controls
